@@ -2,9 +2,9 @@
 # -*- encoding: utf-8 -*-
 import logging
 import re
+from urllib.parse import unquote
 
 import requests
-import six
 from caldav.elements import cdav
 from caldav.elements import dav
 from caldav.elements import ical
@@ -22,11 +22,6 @@ from caldav.objects import ScheduleOutbox
 from caldav.requests import HTTPBearerAuth
 from lxml import etree
 
-if six.PY3:
-    from urllib.parse import unquote
-else:
-    from urlparse import unquote
-
 
 class DAVResponse:
     """
@@ -326,6 +321,7 @@ class DAVClient:
         timeout=None,
         ssl_verify_cert=True,
         ssl_cert=None,
+        headers={},
     ):
         """
         Sets up a HTTPConnection object towards the server in the url.
@@ -362,11 +358,14 @@ class DAVClient:
             log.debug("init - proxy: %s" % (self.proxy))
 
         # Build global headers
-        self.headers = {
-            "User-Agent": "Mozilla/5.0",
-            "Content-Type": "text/xml",
-            "Accept": "text/xml, text/calendar",
-        }
+        self.headers = headers
+        self.headers.update(
+            {
+                "User-Agent": "Mozilla/5.0",
+                "Content-Type": "text/xml",
+                "Accept": "text/xml, text/calendar",
+            }
+        )
         if self.url.username is not None:
             username = unquote(self.url.username)
             password = unquote(self.url.password)
@@ -553,7 +552,7 @@ class DAVClient:
     def extract_auth_types(self, header):
         auth_types = header.lower().split(",")
         auth_types = map(lambda auth_type: auth_type.strip(), auth_types)
-        auth_types = map(lambda auth_type: auth_type[: auth_type.find(" ")], auth_types)
+        auth_types = map(lambda auth_type: auth_type.split(" ")[0], auth_types)
         return list(filter(lambda auth_type: auth_type, auth_types))
 
     def request(self, url, method="GET", body="", headers={}):
